/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Utils 0.1
import "../Components"

Item {
    id: root
    property bool filter: true
    property bool expandable: true
    property var model: null
    property int collapsedRowCount: 2

    property alias minimumHorizontalSpacing: iconTileGrid.minimumHorizontalSpacing
    property alias maximumNumberOfColumns: iconTileGrid.maximumNumberOfColumns
    property alias columns: iconTileGrid.columns
    property alias delegateWidth: iconTileGrid.delegateWidth
    property alias delegateHeight: iconTileGrid.delegateHeight
    property alias verticalSpacing: iconTileGrid.verticalSpacing
    property alias delegate: iconTileGrid.delegate
    property alias cellWidth: iconTileGrid.cellWidth
    property alias cellHeight: iconTileGrid.cellHeight

    height: childrenRect.height

    // TODO: Evaluate better ways how to know where to split to show the Preview
    function itemX(index) {
        var col = index % iconTileGrid.columns;
        return (delegateWidth + horizontalCenter) * col;
    }

    function itemY(index) {
        var row = Math.floor(index / iconTileGrid.columns);
        return (delegateHeight + verticalSpacing) * row;
    }

    ResponsiveGridView {
        id: iconTileGrid

        anchors { left: parent.left; right: parent.right }
        height: totalContentHeight
        Behavior on height { NumberAnimation { id: heightAnimation; duration: 200; easing.type: Easing.InOutQuad } }
        interactive: false

        minimumHorizontalSpacing: units.gu(0.5)
        maximumNumberOfColumns: 6
        delegateWidth: units.gu(11)
        delegateHeight: units.gu(9.5)
        verticalSpacing: units.gu(2)

        model: SortFilterProxyModel {
            model: root.model
            limit: (filter) ? collapsedRowCount * iconTileGrid.columns : -1
        }

        delegate: Tile {
            width: iconTileGrid.cellWidth
            height: iconTileGrid.cellHeight
            text: name
            imageWidth: units.gu(8)
            imageHeight: units.gu(8)
            source: "../graphics/applicationIcons/" + icon + ".png"
            onClicked: shell.activateApplication(desktopFile)
        }
    }

    Item {
        anchors {
            left: parent.left
            right: parent.right
            top: iconTileGrid.bottom
        }
        visible: (expandable && filter && model.count > collapsedRowCount * iconTileGrid.columns)
        height: (visible) ? childrenRect.height + units.gu(2) : 0

        AbstractButton {
            id: button

            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
            }
            width: units.gu(22)
            height: units.gu(4)

            UbuntuShape {
                anchors.fill: parent
                color: "#33ffffff"
                radius: "small"
            }

            UbuntuShape {
                id: borderPressed

                anchors.fill: parent
                radius: "small"
                borderSource: ItemStyle.style.borderPressed
                opacity: button.pressed ? 1.0 : 0.0
                Behavior on opacity { NumberAnimation { duration: 200; easing.type: Easing.OutQuint } }
            }

            Label {
                anchors {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    right: parent.right
                    leftMargin: units.gu(1)
                    rightMargin: units.gu(1)
                }
                text: (filter) ? "+ View all (" + model.count + ")" : "- Show fewer"
                fontSize: "small"
                color: "#f3f3e7"
                opacity: 0.6
                style: Text.Raised
                styleColor: "black"
                elide: Text.ElideMiddle
                horizontalAlignment: Text.AlignHCenter
            }

            onClicked: filter = !filter
        }
    }
}
