/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../Components"

MouseArea {
    anchors.fill: parent

    property bool guestAccount: loginLoader.status == Loader.Ready && loginLoader.item.guestAccount
    property bool ready: wallpaper.status == Image.Ready

    CrossFadeImage {
        id: wallpaper

        source: shell.background
        anchors.fill: parent
        crossFade: false
        fadeInFirst: false
    }

    Rectangle {
        anchors.fill: parent
        color: "black"
        opacity: 0.4
    }

    Clock {
        id: clock
        visible: narrowMode

        anchors {
            top: parent.top
            topMargin: units.gu(2)
            horizontalCenter: parent.horizontalCenter
        }
    }

    Loader {
        id: loginLoader
        objectName: "loginLoader"
        anchors {
            left: parent.left
            leftMargin: units.gu(20)
            verticalCenter: parent.verticalCenter
        }
        width: units.gu(29)
        height: parent.height

        source: greeter.multiUser ? "LoginList.qml" : ""

        onLoaded: {
            item.currentIndex = greeterContentLoader.currentIndex
        }

        Binding {
            target: loginLoader.item
            property: "model"
            value: greeterContentLoader.model
        }

        Connections {
            target: loginLoader.item

            onSelected: {
                shell.background = userList.get(uid).background;
            }

            onUnlocked: {
                greeter.hide();
            }

            onCurrentIndexChanged: {
                greeterContentLoader.currentIndex = loginLoader.item.currentIndex;
            }
        }
    }

    CrossFadeImage {
        id: infographics
        width: narrowMode ? sourceSize.width : units.gu(90)
        height: narrowMode ? sourceSize.height : units.gu(80)

        anchors {
            verticalCenter: parent.verticalCenter
            right: parent.right
            rightMargin: narrowMode ? units.gu(3) : units.gu(-6)
        }
        source: narrowMode ? "graphics/infographic_tweeter_cut.png" : userList.get(greeterContentLoader.currentIndex).infographic ? userList.get(greeterContentLoader.currentIndex).infographic : ""
    }
}
