/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: actionButton

    property string label

    property string buttonGraphic: ""
    property string pressedGraphic: ""
    property string hoverGraphic: ""

    // these are used if no buttonGraphic is available
    property color fillColor: "transparent"
    property real fillAlpha: 0.3
    property color borderColor: Qt.rgba(1.0, 1.0, 1.0, actionButton.fillAlpha)

    property int touchAreaMargins: 0

    signal selected()

    states: [
        State {
            name: "hover"
            PropertyChanges {
                target: actionButton
                fillAlpha: 0.5
            }
        },
        State {
            name: "down"
            PropertyChanges {
                target: actionButton
                fillAlpha: 1
            }
        }
    ]

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        anchors.margins: touchAreaMargins
        hoverEnabled: true
        onEntered: actionButton.state = "hover";
        onExited: actionButton.state = ""
        onPressed: actionButton.state = "down"
        onReleased: {
            if (containsMouse) {
                actionButton.selected()
                actionButton.state = "hover"
            }
        }
    }

    BorderImage {
        id: image
        anchors.fill: parent
        border { left: units.dp(7); top: units.dp(7); right: units.dp(7); bottom: units.dp(7) }
        horizontalTileMode: BorderImage.Stretch
        verticalTileMode: BorderImage.Stretch
        source: {
            if (actionButton.state == "down") {
                return actionButton.pressedGraphic != "" ? actionButton.pressedGraphic : actionButton.buttonGraphic
            }
            else if (actionButton.state == "hover") {
                return actionButton.hoverGraphic != "" ? actionButton.hoverGraphic : actionButton.buttonGraphic
            }
            else {
                return actionButton.buttonGraphic
            }
        }
    }

    Rectangle {
        id: rectangle

        anchors.fill: parent
        color: actionButton.fillColor
        border.color: actionButton.borderColor
        border.width: units.dp(1)
        radius: units.gu(1)
        visible: actionButton.buttonGraphic == ""

        Rectangle {
            anchors.fill: parent
            color: "black"
            opacity: 0.2
            visible: mouseArea.pressed
        }
    }

    Rectangle {
        id: highlightRectangle

        anchors.fill: parent
        color: actionButton.fillColor
        border.color: actionButton.borderColor
        border.width: units.dp(1)
        radius: units.gu(1)
        visible: actionButton.buttonGraphic == ""

        Rectangle {
            anchors.fill: parent
            color: "black"
            opacity: 0.2
            visible: mouseArea.pressed
        }
    }

    TextDropShadow {
        target: textLabel
        opacity: 0.15
    }

    Label {
        id: textLabel
        text: actionButton.label
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        fontSize: "medium"
        color: "white"
    }
}

