/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "settings.js" as Settings

Item {
    id: bubble
    
    property int topMargin: snapDecision ? units.gu(2) : units.gu(1)
    property int bottomMargin: snapDecision ? units.gu(2) : units.gu(1)
    property bool contracted: true
    property string icon
    property string title
    property string subtitle
    property var actions
    property bool clickable: true
    property bool snapDecision: actions != null

    height: content.height + topMargin + bottomMargin
    //Behavior on height {NumberAnimation {duration: Settings.unityFastBeat; easing.type: Settings.easing }}

    signal clicked()
    signal selected()

    signal dragStarted()
    signal dismissed()
    signal restarted()

    signal focusChanged(bool focused)

    states: [
        State {
            name: "contracted"
            PropertyChanges { target: bubble; topMargin: units.gu(1); bottomMargin: units.gu(1) }
        },
        State {
            name: "expanded"
        }
    ]
    
    function restartFadeout() {
        fadeOutAnimation.restart()
    }

    BorderImage {
        id: snapDecisionBackground
        source: "graphics/background.png"
        anchors.fill: parent
        border.left: units.dp(12); border.top: units.dp(12)
        border.right: units.dp(12); border.bottom: units.dp(12)
        opacity: 1
        visible: snapDecision
        smooth: true
    }

    BorderImage {
        id: clickableBackground
        source: mouseArea.pressed ? "graphics/clickable-base-push.png" : "graphics/clickable-base.png"
        anchors.fill: parent
        border.left: units.dp(12); border.top: units.dp(12)
        border.right: units.dp(12); border.bottom: units.dp(12)
        opacity: 1
        visible: bubble.clickable && !snapDecision
        smooth: true
    }

    BorderImage {
        id: nonClickableBackground
        source: "graphics/non-clickable-base.png"
        anchors.fill: parent
        border.left: units.dp(6); border.top: units.dp(6)
        border.right: units.dp(6); border.bottom: units.dp(6)
        visible: !bubble.clickable && !snapDecision
        opacity: 0.5
    }


    MouseArea {
        id: mouseArea
        property int initialY
        property bool toDismiss: initialY - bubble.y > units.gu(3)
        drag {
            target: bubble.snapDecision || !clickable ? null: bubble
            axis: Drag.YAxis
            minimumY: -bubble.height
            maximumY: 0
            onActiveChanged: mouseArea.drag.active ? bubble.dragStarted() : (mouseArea.toDismiss ? bubble.dismissed() : bubble.restarted())
        }
        anchors.fill: parent
        onPressed: initialY = bubble.y
        onClicked: bubble.clicked()
        onReleased: {
            if (mouseArea.toDismiss) {
                dismissAnimation.to = -1.5*bubble.height
            } else {
                dismissAnimation.to = 0
            }
            dismissAnimation.start()
        }
    }

    Content {
        id: content
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.topMargin: bubble.topMargin
        state: bubble.state
        actions: bubble.actions
        Behavior on anchors.topMargin {NumberAnimation { duration: Settings.unityFastBeat; easing.type: Settings.easing }}
    }

    NumberAnimation {
        id: dismissAnimation
        target: bubble
        property: "y"
        easing.type: Easing.OutQuad
        duration: 400
        to: -1.5*bubble.height
    }

    SequentialAnimation {
        id: fadeOutAnimation
        NumberAnimation {
            target: nonClickableBackground
            duration: 5000
            from: 1
            to: 0.5
            property: "opacity"
        }
    }
}
