/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "settings.js" as Settings

Item {
    id: content

    height: body.height
    property var actions

    states: [
        State {
            name: "contracted"
            PropertyChanges { target: expandedContent; opacity: 0.0; height: 0; anchors.topMargin: 0 }
            StateChangeScript {
                script: splitButton.contract()
            }
        },
        State {
            name: "expanded"
            PropertyChanges { target: iconItem; width: units.gu(3); height: units.gu(3) }
        }
    ]

    Item {
        id: body

        anchors.left: content.left
        anchors.leftMargin: units.gu(1)
        anchors.right: content.right
        anchors.rightMargin: units.gu(1)
        height: childrenRect.height

        Item {
            id: iconFrame

            Image {
                id: iconItem
                source: bubble.icon // FIXME: reference to bubble
                smooth: true
                anchors.fill: parent

                Behavior on width {NumberAnimation { duration: Settings.unityFastBeat; easing.type: Settings.easing }}
                Behavior on height {NumberAnimation { duration: Settings.unityFastBeat; easing.type: Settings.easing }}
                fillMode: Image.PreserveAspectFit

                anchors.horizontalCenter: parent.horizontalCenter
            }

            width: height * iconItem.sourceSize.width / iconItem.sourceSize.height // preserve the original aspect ratio
            height: units.gu(7)
        }

        Item {
            id: contractedContent

            height: childrenRect.height
            anchors.left: iconFrame.right
            anchors.leftMargin: units.gu(2)
            anchors.right: parent.right

            Label {
                id: titleItem

                anchors.left: parent.left
                anchors.right: parent.right
                anchors.verticalCenter: bubble.subtitle == "" ? parent.verticalCenter : undefined // FIXME: reference to bubble
                elide: Text.ElideRight
                fontSize: "large"
                text: bubble.title // FIXME: reference to bubble
                color: bubble.clickable || bubble.snapDecision ? "white" : "#333333"
                //font.bold: true
                style: Text.Raised
                styleColor: Qt.rgba(0.0, 0.0, 0.0, 0.4)

                Rectangle {
                    anchors.fill: parent
                    color: "yellow"
                    opacity: 0
                }
            }

            Label {
                id: subtitleItem

                Rectangle {
                    anchors.fill: parent
                    color: "white"
                    opacity: 0
                }
                anchors.top: titleItem.bottom
                anchors.topMargin: units.gu(1)
                anchors.left: parent.left
                anchors.right: parent.right
                height: bubble.snapDecision ? lineCount*font.pixelSize : units.gu(1) + lineCount*font.pixelSize
                wrapMode: Text.Wrap
                maximumLineCount: 2
                elide: Text.ElideRight
                fontSize: "medium"
                text: bubble.subtitle // FIXME: reference to bubble
                color: bubble.clickable || bubble.snapDecision ? "white" : "#333333"
                //font.bold: true
                style: Text.Raised
                styleColor: Qt.rgba(0.0, 0.0, 0.0, 0.4)
            }
        }

        Item {
            id: expandedContent

            height: childrenRect.height
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: iconFrame.bottom
            anchors.topMargin: units.gu(2)

            Item {
                id: actions

                visible: content.actions != null
                //anchors.top: subtitleItem.bottom
                anchors.topMargin: units.gu(1)
                height: visible ? childrenRect.height + units.dp(1) : 0
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.rightMargin: units.dp(2)

                Row {
                    property int halfWidth: (actions.width - spacing) / 2
                    spacing: units.gu(2)
                    height: childrenRect.height
                    SplitButton {
                        id: splitButton
                        label: content.actions ? content.actions.action1 : ""
                        width: content.state == "expanded" ? actions.width : parent.halfWidth // FIXME
                        Behavior on width {NumberAnimation { duration: Settings.unitySlowBeat; easing.type: Settings.easing }}
                        onStateChanged: if (state == "expanded") bubble.state = "expanded" // FIXME: reference to bubble
                                        else bubble.state = ""
                        buttonHeight: units.gu(5)
                        expandedButtonHeight: units.gu(6)
                        onSelected: bubble.selected()
                        onMenuOpened: bubble.focusChanged(true)
                        onMenuClosed: bubble.focusChanged(false)
                    }

                    ActionButton {
                        id: acceptButton
                        buttonGraphic: "graphics/btn_Accept.png"
                        pressedGraphic: "graphics/btn_Accept_Push.png"
                        label: content.actions ? content.actions.action2 : ""
                        width: parent.halfWidth // FIXME
                        opacity: content.state == "expanded" ? 0.0 : 1.0
                        height: units.gu(5)
                        touchAreaMargins: -units.gu(1)

                        Behavior on opacity {NumberAnimation { duration: Settings.unitySlowBeat; easing.type: Settings.easing }}

                        onSelected: bubble.selected()
                    }
                }
            }
        }
    }
}
