/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1


ShaderEffect {
    property color inColor: Qt.rgba(1.0, 0.0, 0.0, 1.0)
    property color outColor: Qt.hsla(0.0, 0.0, 0.0, 0.0)
    property int radius: units.gu(13)
    property int originX: 10
    property int originY: 10

    property real aspectRatio: width / height
    property real radiusRelative: radius / width
    property real originXRelative: originX / width
    property real originYRelative: originY / height

    fragmentShader:
        "
        varying mediump vec2 qt_TexCoord0;
        uniform lowp vec4 inColor;
        uniform lowp vec4 outColor;
        uniform highp float radiusRelative;
        uniform highp float originXRelative;
        uniform highp float originYRelative;
        uniform highp float aspectRatio;
        uniform highp float qt_Opacity;

        void main(void)
        {
            mediump vec2 origin = vec2(originXRelative, (1.0 - originYRelative) / aspectRatio );
            highp float fragmentDistance = distance(vec2(qt_TexCoord0.s, qt_TexCoord0.t / aspectRatio), origin);
            highp float strength = clamp(fragmentDistance / radiusRelative, 0.0, 1.0);
            highp vec4 result = mix(inColor, outColor, strength);
            gl_FragColor = result * result.a * qt_Opacity;
        }
        "
}
