/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: notificationButtons

    property int snapDecisionCount
    property int clickableCount
    property int notificationCount

    width: units.gu(9)
    height: units.gu(5)

    signal newSnapDecision()
    signal newNotification()
    signal newClickableNotification()
    signal dismissCurrent()

    function __showNotification(type) {
        if (type == 0) {
            notificationButtons.dismissCurrent()
        } else if (type == 1) {
            notificationButtons.newSnapDecision()
        } else if (type == 2) {
            notificationButtons.newClickableNotification()
        } else if (type == 3) {
            notificationButtons.newNotification()
        }
    }

    Row {
        id: buttonRow
        width: childrenRect.width
        height: childrenRect.height
        anchors.horizontalCenter: parent.horizontalCenter
        Repeater {
            model: notificationModel
            Item {
                width: Math.floor(notificationButtons.width/notificationModel.count) - units.dp(1)
                height: notificationButtons.height
                Rectangle {
                    id: bg
                    anchors.fill: parent
                    color: "black"
                    opacity: 0.8
                    border.width: units.dp(1)
                    border.color: "white"
                }
                MouseArea {
                    id: mouseArea
                    anchors.fill: parent
                    onClicked: notificationButtons.__showNotification(type)
                }
                Label {
                    anchors.centerIn: bg
                    color: "white"
                    fontSize: "medium"
                    text: model.text
                    opacity: mouseArea.pressed ? 1 : 0.7
                }
                Label {
                    id: count
                    text: {
                        if (type == 1) return snapDecisionCount
                        else if (type == 2) return clickableCount
                        else if (type == 3) return notificationCount
                        else return ""
                    }

                    color: "gray"
                    fontSize: "medium"
                    anchors.bottom: parent.bottom
                    anchors.right: parent.right
                    anchors.margins: units.dp(1)
                }
            }
        }
    }

    ListModel {
        id: notificationModel
        ListElement{
            text: "SD"
            type: 1
        }
        ListElement{
            text: "Clickable"
            type: 2
        }
        ListElement{
            text: "Notificat."
            type: 3
        }
        ListElement{
            text: "Dismiss"
            type: 0
        }
    }
}

