/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../../Components"
import Ubuntu.Components 0.1

FocusScope {
    id: root
    width: units.gu(10)
    height: units.gu(10)
    focus: true

    signal keyPressReceived()

    TestCase {
        when: windowShown

        function test_mouse_data() {
            return [
                {tag: "InputFilterArea disabled", blocking: false, count: 1, message: "Mouse click was blocked even though it shouldn't have been blocked"},
                {tag: "InputFilterArea enabled", blocking: true, count: 0, message: "Mouse click was received even though it should have been blocked"},
            ]
        }

        function test_mouse(data) {
            inputFilterArea.blockInput = data.blocking
            mouseSpy.clear()
            mouseClick(testMouseArea, testMouseArea.width / 2, testMouseArea.height / 2)
            compare(mouseSpy.count, data.count, data.message)
        }

        function test_keyboard_data() {
            return [
                {tag: "InputFilterArea disabled", blocking: false, count: 1, message: "Keyboard key was blocked even though it shouldn't have been blocked"},
                {tag: "InputFilterArea enabled",  blocking: true,  count: 0, message: "Keyboard key was blocked even though it should have been blocked"},
            ]
        }

        function test_keyboard(data) {
            inputFilterArea.blockInput = data.blocking
            keyboardSpy.clear()
            keyClick(Qt.Key_Left)
            compare(keyboardSpy.count, data.count, data.message)
        }

    }

    Keys.onPressed: root.keyPressReceived()

    MouseArea {
        id: testMouseArea
        anchors.fill:parent

        InputFilterArea {
            id: inputFilterArea
            anchors.fill: parent
        }
    }

    SignalSpy {
        id: mouseSpy
        target: testMouseArea
        signalName: "clicked"
    }
    SignalSpy {
        id: keyboardSpy
        target: root
        signalName: "keyPressReceived"
    }
}
